cffi: Foreign Function Interface for Python calling C code
==========================================================

Description
-----------

development website: https://foss.heptapod.net/pypy/cffi

documentation website: https://cffi.readthedocs.io/en/latest/

PyPI page: https://pypi.org/project/cffi/

License
-------

MIT

Upstream Contact
----------------

https://foss.heptapod.net/pypy/cffi
